@@ -5,7 +5,8 @@ urlpath = get_setting('module', 'memberships', 'url')
 if not urlpath:
     urlpath = "memberships"
 
-urlpatterns = patterns("tendenci.addons.memberships.views",
+urlpatterns = patterns(
+    "tendenci.addons.memberships.views",
 
     # memberships
     url(r"^%s/$" % urlpath, "membership_index", name="membership.index"),
@@ -78,7 +79,7 @@ urlpatterns = patterns("tendenci.addons.memberships.views",
     url(r"^%s/verifyemail/(?P<id>\d+)/(?P<guid>[\d\w-]+)/$" % urlpath,
         "verify_email",
         name="membership.verify_email"),
-    
+
     url(r"^%s/applications/add/(?P<cm_id>\d+)/$" % urlpath,
         "membership_default_add", {'join_under_corporate': True},
         name="membership_default.add_under_corp"),
@@ -93,15 +94,19 @@ urlpatterns = patterns("tendenci.addons.memberships.views",
     url(r"^%s/applications/(?P<slug>[\w\-]+)/preview/$" % urlpath,
         "membership_default_preview",
         name="membership_default.preview"),
+
     # legacy link for default add
     url(r"^%s/applications/add/$" % urlpath,
         "membership_default_add_legacy",
         name="membership_default.add"),
+
     # membership default add
     url(r"^%s/applications/(?P<slug>[\w\-]+)/$" % urlpath,
         "membership_default_add",
         name="membership_default.add"),
 
+    url(r"^%s/applications/$" % urlpath, "membership_applications", name="membership-applications"),
+    url(r"^%s/referer-url/$" % urlpath, "referer_url", name="membership-referer-url"),
 
     # reports
     url(r'^%s/reports/$' % urlpath, 'report_list', name='reports-memberships'),
